#pragma once

#include <iostream>
#include <vector>
#include <memory>
#include <sstream>
#include <optional>
#include <fstream>
#include <cmath>
#include <unordered_map>
#include <unordered_set>
